#!/bin/sh
# this file is sourced not run

# Set traps and create temporary folder. {{{1
TMPD=$(mktemp -d -p "${TMPDIR:-/tmp}" "${0##*/}_XXXXXX")
# created with permissions u+rwx minus umask restrictions
chmod 700 "$TMPD" || exit 1
trap "[ \${STATUS:?} -eq 0 ] && rm -rf \"${TMPD:?}\"; exit \$STATUS" \
	HUP INT ALRM TERM 0 # USR1 USR2

# {{{1}}}
mkdir -p "$TMPD"

MDVIEW=${MDVIEW:-mdview}
DIFF=${DIFF:-diff}

TEST_EXPECT_DIR='test/expect'
TEST_OUTS="$TMPD/${TEST_LABEL:?}"
TEST_EXPECTS="${TEST_EXPECT_DIR:?}/${TEST_LABEL:?}"

# $* html|tty|text ...
test_create_expect () { # => STATUS
	local p ret
	STATUS=0
	for p in "${@:-html}"; do
		ret=1
		${MDVIEW:?} $TEST_ARGS --$p > "${TEST_EXPECTS:?}.$p"
		ret=$?
		[ $ret -eq 0 ] &&
			printf "\033[7m  %s  \033[0m %s %s\n" \
			"CREATED" "${TEST_LABEL:?}" "$p" ||
			printf "\033[7;31m  %s  \033[0m %s %s\n" \
			"ERROR" "${TEST_LABEL:?}" "$p"
		[ $ret -eq 0 ] || STATUS=1
	done
	return $STATUS
}

# $* html|tty|text ...
test_run () {
	local p ret
	for p in "${@:-html}"; do
		${MDVIEW:?} $TEST_ARGS --$p > "${TEST_OUTS:?}.$p"
		[ $? -eq 0 ] || ret=1
	done
	return $ret
}

# $* html|tty|text ...
test_diff () {
	local p ret
	for p in "${@:-html}"; do
		${DIFF:?} "${TEST_EXPECTS:?}.$p" "${TEST_OUTS:?}.$p"
		[ $? -eq 0 ] || ret=1
	done
	return $ret
}

# $* html|tty|text ...
main () { # => $STATUS
	local p ret
	STATUS=0
	for p in "${@:-html}"; do
		ret=1
		test_run "$p"
		ret=$?
		[ $ret -eq 0 ] && test_diff "$p"
		ret=$?
		[ $ret -eq 0 ] || STATUS=1
		[ $ret -eq 0 ] &&
			printf "\033[7m  %s  \033[0m %s %s\n" \
			"PASS" "${TEST_LABEL:?}" "$p" ||
			printf "\033[7;31m  %s  \033[0m %s %s\n" \
			"FAIL" "${TEST_LABEL:?}" "$p"
	done
	return $STATUS
}
